(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
  typeof define === 'function' && define.amd ? define(factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, global.rek = factory());
})(this, (function () { 'use strict';

  class FetchError extends Error {
    constructor(response, body) {
      super(response.statusText);
      this.name = 'FetchError';
      this.status = response.status;
      this.response = response;
      this.body = body;
    }
  }

  var requestMethods = ['delete', 'get', 'head'];
  var dataMethods = ['patch', 'post', 'put'];
  var responseTypes = {
    arrayBuffer: '*/*',
    blob: '*/*',
    formData: 'multipart/form-data',
    json: 'application/json',
    text: 'text/*'
  };
  function factory(defaults) {
    function rek(url, options) {
      if (typeof options === 'string') options = {
        response: options
      };
      options = Object.assign({}, defaults, options);
      if (options.baseUrl) {
        url = new URL(url, options.baseUrl).href;
      }
      if (options.searchParams) {
        url = url.split('?')[0] + '?' + new URLSearchParams(options.searchParams);
      }
      options.headers = new options.Headers(Object.assign({}, defaults.headers, options.headers));
      var {
        body,
        headers,
        response,
        fetch
      } = options;
      if (body && typeof body === 'object') {
        if (typeof body.append === 'function') {
          headers.delete('content-type');
        } else if (typeof (body.getReader || body.stream) !== 'function' && (typeof body.byteLength !== 'number' || typeof (body.slice || body.getInt8) !== 'function')) {
          options.body = JSON.stringify(body);
          headers.set('content-type', 'application/json');
        }
      }
      var onFullfilled = response && (typeof response === 'function' ? response : (headers.set('accept', responseTypes[response]), res => res.status === 204 ? null : res[response]()));
      var res = fetch(url, options).then(res => {
        if (res.ok) return res;
        return res.text().then(text => {
          try {
            return JSON.parse(text);
          } catch (_unused) {
            return text || null;
          }
        }).catch(() => null).then(body => {
          throw new FetchError(res, body);
        });
      });
      return res.then(onFullfilled);
    }
    requestMethods.forEach(method => {
      rek[method] = (url, options) => rek(url, Object.assign({}, options, {
        method: method.toUpperCase()
      }));
    });
    dataMethods.forEach(method => {
      rek[method] = (url, body, options) => rek(url, Object.assign({}, options, {
        body,
        method: method.toUpperCase()
      }));
    });
    rek.extend = newDefaults => factory(Object.assign({}, defaults, newDefaults, {
      headers: Object.assign({}, defaults.headers, newDefaults.headers)
    }));
    return rek;
  }

  var native = factory({
    credentials: 'same-origin',
    response: 'json',
    fetch,
    Headers
  });

  return native;

}));
//# sourceMappingURL=rek.umd.js.map
